# SEC03-BP07: Analyze public and cross-account access

## Description

Monitor public/cross-account access.

## Implementation Guidance

- Public access detection
- Cross-account trust analysis
- External sharing inventory
- Regular access reviews
- Automated alerts

## Risk Level

High - Unmonitored external access is dangerous.
